error_if_agument_is_not_character_string: Throw error if argument is not a character string

View source: R/note_warning_error.R

error_if_agument_is_not_character_stringR Documentation

Throw error if argument is not a character string

Description

Throw error if argument is not a character string

Usage

error_if_agument_is_not_character_string(name, value)

pxmake documentation built on April 18, 2026, 5:08 p.m.