px_datasymbol3.px: DATASYMBOL3

View source: R/modify_table2.R

px_datasymbol3R Documentation

DATASYMBOL3

Description

Inspect or change DATASYMBOL3.

Usage

px_datasymbol3(x, value, validate)

## S3 method for class 'px'
px_datasymbol3(x, value, validate = TRUE)

Arguments

x

A px object

value

Optional. A character string to set the value for all languages or a data frame with columns 'language' and 'value' to set it for specific languages. If 'value' is missing, the current DATASYMBOL3 is returned. If NULL, DATASYMBOL3 is removed.

validate

Optional. If TRUE a number of validation checks are performed on the px object, and an error is thrown if the object is not valid. If FALSE, the checks are skipped, which can be usefull for large px objects where the check can be time consuming. Use px_validate() to manually preform the check.

Value

A px object, a character string, or a data frame.

See Also

Statistics Sweden's documentation

Examples

# Set DATASYMBOL3 for all languages
x1 <-
  px(population_gl) |>
  px_datasymbol3('missing')

# Print DATASYMBOL3
px_datasymbol3(x1)

# Set DATASYMBOL3 for individual languages
library(tibble)
x2 <-
  x1 |>
  px_languages(c('en', 'kl')) |>
  px_datasymbol3(tribble(~language, ~value,
                      'en', 'missing',
                      'kl', 'amigaataapput'))
px_datasymbol3(x2)

# Remove DATASYMBOL3
x3 <- px_datasymbol3(x2, NULL)
px_datasymbol3(x3)

pxmake documentation built on April 18, 2026, 5:08 p.m.