Learn R Programming

pxmake (version 0.19.0)

px_elimination: ELIMINATION

Description

Inspect or change ELIMINATION.

Usage

px_elimination(x, value, validate)

# S3 method for px px_elimination(x, value, validate = TRUE)

Value

A px object or data frame.

Arguments

x

A px object

value

Optional. Use character to set ELIMINATION for all STUB and HEADING variables. Use a data frame with columns 'variable-code' and 'elimination' to set ELIMINATION for individual variables. If value is missing, the current ELIMINATION is returned. If NULL, ELIMINATION is removed for all variables.

validate

Optional. If TRUE a number of validation checks are performed on the px object, and an error is thrown if the object is not valid. If FALSE, the checks are skipped, which can be usefull for large px objects where the check can be time consuming. Use px_validate() to manually preform the check.

See Also

Examples

Run this code
library(tibble)

# Set ELIMINATION
x1 <-
  px(population_gl) |>
  px_elimination(tribble(~`variable-code`, ~elimination,
                         "gender", "T",
                         "age", "YES"
                        )
                )

# Print ELIMINATION
px_elimination(x1)

# Remove ELIMINATION
x2 <- px_elimination(x1, NULL)
px_elimination(x2)

Run the code above in your browser using DataLab