px_from_data_df: Create a minimal px object from a data frame

View source: R/data_df.R

px_from_data_dfR Documentation

Create a minimal px object from a data frame

Description

Create a minimal px object from a data frame

Usage

px_from_data_df(df)

Arguments

df

A data frame

Value

A px object


pxmake documentation built on April 18, 2026, 5:08 p.m.