Skip to contents

Inspect or change DATASYMBOL5.

Usage

px_datasymbol5(x, value, validate)

# S3 method for class 'px'
px_datasymbol5(x, value, validate = TRUE)

Arguments

x

A px object

value

Optional. A character string to set the value for all languages or a data frame with columns 'language' and 'value' to set it for specific languages. If 'value' is missing, the current DATASYMBOL5 is returned. If NULL, DATASYMBOL5 is removed.

validate

Optional. If TRUE a number of validation checks are performed on the px object, and an error is thrown if the object is not valid. If FALSE, the checks are skipped, which can be usefull for large px objects where the check can be time consuming. Use px_validate() to manually preform the check.

Value

A px object, a character string, or a data frame.

Examples

# Set DATASYMBOL5 for all languages
x1 <-
  px(population_gl) |>
  px_datasymbol5('missing')

# Print DATASYMBOL5
px_datasymbol5(x1)
#> [1] "missing"

# Set DATASYMBOL5 for individual languages
library(tibble)
x2 <-
  x1 |>
  px_languages(c('en', 'kl')) |>
  px_datasymbol5(tribble(~language, ~value,
                      'en', 'missing',
                      'kl', 'amigaataapput'))
px_datasymbol5(x2)
#> # A tibble: 2 × 2
#>   language value        
#>   <chr>    <chr>        
#> 1 en       missing      
#> 2 kl       amigaataapput

# Remove DATASYMBOL5
x3 <- px_datasymbol5(x2, NULL)
px_datasymbol5(x3)
#> NULL