View source: R/modify_table2.R
| px_datasymbol6 | R Documentation |
Inspect or change DATASYMBOL6.
px_datasymbol6(x, value, validate)
## S3 method for class 'px'
px_datasymbol6(x, value, validate = TRUE)
x |
A px object |
value |
Optional. A character string to set the value for all languages or a data frame with columns 'language' and 'value' to set it for specific languages. If 'value' is missing, the current DATASYMBOL6 is returned. If NULL, DATASYMBOL6 is removed. |
validate |
Optional. If TRUE a number of validation checks are performed on the px object, and an error is thrown if the object is not valid. If FALSE, the checks are skipped, which can be usefull for large px objects where the check can be time consuming. Use |
A px object, a character string, or a data frame.
Statistics Sweden's documentation
# Set DATASYMBOL6 for all languages
x1 <-
px(population_gl) |>
px_datasymbol6('missing')
# Print DATASYMBOL6
px_datasymbol6(x1)
# Set DATASYMBOL6 for individual languages
library(tibble)
x2 <-
x1 |>
px_languages(c('en', 'kl')) |>
px_datasymbol6(tribble(~language, ~value,
'en', 'missing',
'kl', 'amigaataapput'))
px_datasymbol6(x2)
# Remove DATASYMBOL6
x3 <- px_datasymbol6(x2, NULL)
px_datasymbol6(x3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.