Skip to contents

Inspect or change DATASYMBOL6.

Usage

px_datasymbol6(x, value, validate)

# S3 method for class 'px'
px_datasymbol6(x, value, validate = TRUE)

Arguments

x

A px object

value

Optional. A character string to set the value for all languages or a data frame with columns 'language' and 'value' to set it for specific languages. If 'value' is missing, the current DATASYMBOL6 is returned. If NULL, DATASYMBOL6 is removed.

validate

Optional. If TRUE a number of validation checks are performed on the px object, and an error is thrown if the object is not valid. If FALSE, the checks are skipped, which can be usefull for large px objects where the check can be time consuming. Use px_validate() to manually preform the check.

Value

A px object, a character string, or a data frame.

Examples

# Set DATASYMBOL6 for all languages
x1 <-
  px(population_gl) |>
  px_datasymbol6('missing')

# Print DATASYMBOL6
px_datasymbol6(x1)
#> [1] "missing"

# Set DATASYMBOL6 for individual languages
library(tibble)
x2 <-
  x1 |>
  px_languages(c('en', 'kl')) |>
  px_datasymbol6(tribble(~language, ~value,
                      'en', 'missing',
                      'kl', 'amigaataapput'))
px_datasymbol6(x2)
#> # A tibble: 2 × 2
#>   language value        
#>   <chr>    <chr>        
#> 1 en       missing      
#> 2 kl       amigaataapput

# Remove DATASYMBOL6
x3 <- px_datasymbol6(x2, NULL)
px_datasymbol6(x3)
#> NULL