Skip to contents

Inspect or change DATASYMBOLNIL.

Usage

px_datasymbolnil(x, value, validate)

# S3 method for class 'px'
px_datasymbolnil(x, value, validate = TRUE)

Arguments

x

A px object

value

Optional. A character string to set the value for all languages or a data frame with columns 'language' and 'value' to set it for specific languages. If 'value' is missing, the current DATASYMBOLNIL is returned. If NULL, DATASYMBOLNIL is removed.

validate

Optional. If TRUE a number of validation checks are performed on the px object, and an error is thrown if the object is not valid. If FALSE, the checks are skipped, which can be usefull for large px objects where the check can be time consuming. Use px_validate() to manually preform the check.

Value

A px object, a character string, or a data frame.

Examples

# Set DATASYMBOLNIL for all languages
x1 <-
  px(population_gl) |>
  px_datasymbolnil('missing')

# Print DATASYMBOLNIL
px_datasymbolnil(x1)
#> [1] "missing"

# Set DATASYMBOLNIL for individual languages
library(tibble)
x2 <-
  x1 |>
  px_languages(c('en', 'kl')) |>
  px_datasymbolnil(tribble(~language, ~value,
                      'en', 'missing',
                      'kl', 'amigaataapput'))
px_datasymbolnil(x2)
#> # A tibble: 2 × 2
#>   language value        
#>   <chr>    <chr>        
#> 1 en       missing      
#> 2 kl       amigaataapput

# Remove DATASYMBOLNIL
x3 <- px_datasymbolnil(x2, NULL)
px_datasymbolnil(x3)
#> NULL